@@ -4,8 +4,8 @@ import contextlib
 
 from IPython.parallel import require
 
-from bcbio.pipeline import sample, lane, shared, variation
-from bcbio.variation import realign, genotype, ensemble, recalibrate, multi
+from bcbio.pipeline import sample, lane, qcsummary, shared, variation
+from bcbio.variation import bamprep, realign, genotype, ensemble, multi, recalibrate
 from bcbio.log import setup_logging, logger
 
 @contextlib.contextmanager
@@ -41,13 +41,24 @@ def trim_lane(*args):
 def process_alignment(*args):
     with _setup_logging(args):
         return apply(lane.process_alignment, *args)
-process_alignment.metadata = {"resources": ["novoalign"]}
+process_alignment.metadata = {"resources": ["novoalign", "bwa"]}
+
+@require(lane)
+def align_prep_full(*args):
+    with _setup_logging(args):
+        return apply(lane.align_prep_full, *args)
+align_prep_full.metadata = {"resources": ["novoalign", "bwa", "gatk"]}
 
 @require(sample)
 def merge_sample(*args):
     with _setup_logging(args):
         return apply(sample.merge_sample, *args)
 
+@require(sample)
+def delayed_bam_merge(*args):
+    with _setup_logging(args):
+        return apply(sample.delayed_bam_merge, *args)
+
 @require(sample)
 def recalibrate_sample(*args):
     with _setup_logging(args):
@@ -74,15 +85,25 @@ def split_variants_by_sample(*args):
     with _setup_logging(args):
         return apply(multi.split_variants_by_sample, *args)
 
-@require(sample)
+@require(bamprep)
+def piped_bamprep(*args):
+    with _setup_logging(args):
+        return apply(bamprep.piped_bamprep, *args)
+
+@require(variation)
 def postprocess_variants(*args):
     with _setup_logging(args):
-        return apply(sample.postprocess_variants, *args)
+        return apply(variation.postprocess_variants, *args)
+
+@require(qcsummary)
+def pipeline_summary(*args):
+    with _setup_logging(args):
+        return apply(qcsummary.pipeline_summary, *args)
 
 @require(sample)
-def process_sample(*args):
+def generate_transcript_counts(*args):
     with _setup_logging(args):
-        return apply(sample.process_sample, *args)
+        return apply(sample.generate_transcript_counts, *args)
 
 @require(sample)
 def generate_bigwig(*args):
