@@ -8,14 +8,14 @@ import sys
 import time
 import contextlib
 import multiprocessing
-import subprocess
+import psutil
 
 from mako.template import Template
 
 from bcbio import utils
 from bcbio.distributed import ipython
 
-def parallel_runner(parallel, dirs, config, config_file):
+def parallel_runner(parallel, dirs, config, config_file=None):
     """Process a supplied function: single, multi-processor or distributed.
     """
     def run_parallel(fn_name, items, metadata=None):
@@ -32,7 +32,8 @@ def parallel_runner(parallel, dirs, config, config_file):
                          fn_name)
             cores = cores_including_resources(int(parallel["cores"]), metadata, config)
             with utils.cpmap(cores) as cpmap:
-                for data in cpmap(fn, filter(lambda x: x is not None, items)):
+                for data in cpmap(fn, (ipython.add_cores_to_config(x, 1)
+                                       for x in items if x is not None)):
                     if data:
                         out.extend(data)
             return out
@@ -112,14 +113,11 @@ def cores_including_resources(cores, metadata, config):
         cores = 1
     return cores
 
+
 def _machine_memory():
-    """Retrieve available memory on current machine using 'free.'
-    """
-    with contextlib.closing(subprocess.Popen(["free", "-g"],
-                                             stdout=subprocess.PIPE).stdout) as stdout:
-        for line in stdout:
-            if line.startswith("Mem:"):
-                return int(line.split()[1])
+    BYTES_IN_GIG = 1073741824
+    free_bytes = psutil.virtual_memory().available
+    return free_bytes / BYTES_IN_GIG
 
 # ## Utility functions
 
