@@ -1,8 +1,9 @@
 """Multiprocessing ready entry points for sample analysis.
 """
 from bcbio import utils
-from bcbio.pipeline import sample, lane, shared, variation
-from bcbio.variation import realign, genotype, ensemble, recalibrate, multi
+from bcbio.bam import callable
+from bcbio.pipeline import lane, qcsummary, sample, shared, variation
+from bcbio.variation import bamprep, realign, genotype, ensemble, multi, recalibrate
 
 @utils.map_wrap
 def process_lane(*args):
@@ -16,10 +17,22 @@ def trim_lane(*args):
 def process_alignment(*args):
     return lane.process_alignment(*args)
 
+@utils.map_wrap
+def align_prep_full(*args):
+    return lane.align_prep_full(*args)
+
 @utils.map_wrap
 def merge_sample(*args):
     return sample.merge_sample(*args)
 
+@utils.map_wrap
+def delayed_bam_merge(*args):
+    return sample.delayed_bam_merge(*args)
+
+@utils.map_wrap
+def piped_bamprep(*args):
+    return bamprep.piped_bamprep(*args)
+
 @utils.map_wrap
 def prep_recal(*args):
     return recalibrate.prep_recal(*args)
@@ -38,11 +51,15 @@ def split_variants_by_sample(*args):
 
 @utils.map_wrap
 def postprocess_variants(*args):
-    return sample.postprocess_variants(*args)
+    return variation.postprocess_variants(*args)
 
 @utils.map_wrap
-def process_sample(*args):
-    return sample.process_sample(*args)
+def pipeline_summary(*args):
+    return qcsummary.pipeline_summary(*args)
+
+@utils.map_wrap
+def generate_transcript_counts(*args):
+    return sample.generate_transcript_counts(*args)
 
 @utils.map_wrap
 def generate_bigwig(*args):
@@ -67,3 +84,11 @@ def detect_sv(*args):
 @utils.map_wrap
 def combine_calls(*args):
     return ensemble.combine_calls(*args)
+
+@utils.map_wrap
+def combine_bed(*args):
+    return callable.combine_bed(*args)
+
+@utils.map_wrap
+def calc_callable_loci(*args):
+    return callable.calc_callable_loci(*args)
