@@ -39,8 +39,8 @@ def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
     return sam_file
 
 def _bwa_args_from_config(config):
-    cores = config.get("resources", {}).get("bwa", {}).get("cores", None)
-    core_flags = ["-t", str(cores)] if cores else []
+    num_cores = config["algorithm"].get("num_cores", 1)
+    core_flags = ["-t", str(num_cores)] if num_cores > 1 else []
     qual_format = config["algorithm"].get("quality_format", "").lower()
     qual_flags = ["-I"] if qual_format == "illumina" else []
     return core_flags + qual_flags
@@ -54,4 +54,3 @@ def _run_bwa_align(fastq_file, ref_file, out_file, config):
     with open(out_file, "w") as out_handle:
         logger.info(" ".join(aln_cl))
         subprocess.check_call(aln_cl, stdout=out_handle)
-
