@@ -3,14 +3,34 @@
 import os
 import copy
 
-from bcbio.log import logger
 from bcbio import utils, broad
-from bcbio.pipeline.fastq import get_fastq_files
-from bcbio.pipeline.demultiplex import split_by_barcode
-from bcbio.pipeline.alignment import align_to_sort_bam
-from bcbio.ngsalign.split import split_read_files
+from bcbio.log import logger
+from bcbio.bam import callable
 from bcbio.bam.trim import brun_trim_fastq, trim_read_through
+from bcbio.pipeline.fastq import get_fastq_files, needs_fastq_conversion
+from bcbio.pipeline.demultiplex import split_by_barcode
+from bcbio.pipeline.alignment import align_to_sort_bam, get_genome_ref
+from bcbio.pipeline import merge, shared, sample
+from bcbio.ngsalign.split import split_read_files
+from bcbio.variation import recalibrate
 
+def _item_needs_compute(lanes):
+    """Determine if any item needs computing resources to spin up a cluster.
+    """
+    for lane_items, _, _, _, config in lanes:
+        # check if multiplexed
+        if len(lane_items) > 1 or lane_items[0]["barcode_id"] is not None:
+            return True
+        # check if we need to process the input by splitting or conversion
+        item = lane_items[0]
+        config = shared.update_config_w_custom(config, item)
+        split_size = config.get("distributed", {}).get("align_split_size",
+                                                   config["algorithm"].get("align_split_size", None))
+        if split_size is not None:
+            return True
+        if needs_fastq_conversion(item, config):
+            return True
+    return False
 
 def _prep_fastq_files(item, bc_files, dirs, config):
     """Potentially prepare input FASTQ files for processing.
@@ -24,20 +44,28 @@ def _prep_fastq_files(item, bc_files, dirs, config):
     else:
         return [[fastq1, fastq2, None]]
 
+def process_all_lanes(lanes, run_parallel):
+    """Process all input lanes, avoiding starting a cluster if not needed.
+    """
+    lanes = list(lanes)
+    if _item_needs_compute(lanes):
+        return run_parallel("process_lane", lanes)
+    else:
+        return [apply(process_lane, xs)[0] for xs in lanes]
+
 def process_lane(lane_items, fc_name, fc_date, dirs, config):
     """Prepare lanes, potentially splitting based on barcodes.
     """
     lane_name = "%s_%s_%s" % (lane_items[0]['lane'], fc_date, fc_name)
-    logger.info("Demulitplexing %s" % lane_name)
-    full_fastq1, full_fastq2 = get_fastq_files(dirs["fastq"], dirs["work"],
-                                               lane_items[0], fc_name,
-                                               dirs=dirs,
-                                               config=_update_config_w_custom(config, lane_items[0]))
+    logger.info("Preparing %s" % lane_name)
+    full_fastq1, full_fastq2 = get_fastq_files(dirs["fastq"],
+      dirs["work"], lane_items[0], fc_name, dirs=dirs,
+      config=shared.update_config_w_custom(config, lane_items[0]))
     bc_files = split_by_barcode(full_fastq1, full_fastq2, lane_items,
                                 lane_name, dirs, config)
     out = []
     for item in lane_items:
-        config = _update_config_w_custom(config, item)
+        config = shared.update_config_w_custom(config, item)
         # Can specify all barcodes but might not have actual sequences
         # Would be nice to have a good way to check this is okay here.
         if bc_files.has_key(item["barcode_id"]):
@@ -52,16 +80,6 @@ def process_lane(lane_items, fc_name, fc_date, dirs, config):
                     cur_lane_name += "_s{0}".format(lane_ext)
                 out.append((fastq1, fastq2, item, cur_lane_name, cur_lane_desc,
                             dirs, config))
-                """
-                if config["algorithm"].get("trim_reads", False):
-                    trim_info = brun_trim_fastq([x for x in [fastq1, fastq2] if x is not None],
-                                                dirs, config)
-                    fastq1 = trim_info[0]
-                    if fastq2 is not None:
-                        fastq2 = trim_info[1]
-                out.append((fastq1, fastq2, item, cur_lane_name, cur_lane_desc,
-                            dirs, config))
-                            """
     return out
 
 
@@ -104,6 +122,7 @@ def trim_lane(fastq1, fastq2, info, lane_name, lane_desc, dirs, config):
 
     return [(fastq1, fastq2, info, lane_name, lane_desc, dirs, config)]
 
+# ## Alignment
 
 def process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
                       dirs, config):
@@ -113,8 +132,8 @@ def process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
     out_bam = ""
     if os.path.exists(fastq1) and aligner:
         logger.info("Aligning lane %s with %s aligner" % (lane_name, aligner))
-        out_bam = align_to_sort_bam(fastq1, fastq2, info["genome_build"], aligner,
-                                    lane_name, lane_desc, dirs, config)
+        out_bam, ref_file = align_to_sort_bam(fastq1, fastq2, info["genome_build"], aligner,
+                                              lane_name, lane_desc, dirs, config)
     elif os.path.exists(fastq1) and fastq1.endswith(".bam"):
         sort_method = config["algorithm"].get("bam_sort")
         if sort_method:
@@ -124,22 +143,38 @@ def process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
             out_bam = runner.run_fn("picard_sort", fastq1, sort_method, out_file)
         else:
             out_bam = fastq1
-    return [{"fastq": [fastq1, fastq2], "out_bam": out_bam, "info": info,
-             "config": config}]
+    return [{"fastq": [fastq1, fastq2], "work_bam": out_bam, "info": info,
+             "sam_ref": ref_file, "config": config}]
 
-def _update_config_w_custom(config, lane_info):
-    """Update the configuration for this lane if a custom analysis is specified.
+def align_prep_full(fastq1, fastq2, info, lane_name, lane_desc,
+                    dirs, config, config_file):
+    """Perform alignment and post-processing required on full BAM files.
+    Prepare list of callable genome regions allowing subsequent parallelization.
     """
-    name_remaps = {"variant": ["SNP calling", "variant"],
-                   "SNP calling": ["SNP calling", "variant"]}
-    config = copy.deepcopy(config)
-    base_name = lane_info.get("analysis")
-    for analysis_type in name_remaps.get(base_name, [base_name]):
-        custom = config["custom_algorithms"].get(analysis_type, None)
-        if custom:
-            for key, val in custom.iteritems():
-                config["algorithm"][key] = val
-    # apply any algorithm details specified with the lane
-    for key, val in lane_info.get("algorithm", {}).iteritems():
-        config["algorithm"][key] = val
-    return config
+    align_out = process_alignment(fastq1, fastq2, info, lane_name, lane_desc,
+                                  dirs, config)[0]
+    data = _organize_merge_samples(align_out, dirs, config_file)
+    data["regions"] = callable.block_regions(data["work_bam"],
+                                             data["sam_ref"], config)
+    data = _recal_no_markduplicates(data)
+    return [data]
+
+def _recal_no_markduplicates(data):
+    orig_config = copy.deepcopy(data["config"])
+    data["config"]["algorithm"]["mark_duplicates"] = False
+    data = recalibrate.prep_recal(data)[0][0]
+    data["config"] = orig_config
+    return data
+
+def _organize_merge_samples(align_out, dirs, config_file):
+    """Back compatibility handling organizing and merging samples.
+    """
+    samples = merge.organize_samples([align_out], dirs, config_file)
+    assert len(samples) == 1 and len(samples[0]) == 1
+    sample_data = samples[0][0]
+    sample_data["dirs"]["work"] = os.path.dirname(align_out["work_bam"])
+    samples2 = sample.merge_sample(sample_data)
+    assert len(samples2) == 1 and len(samples2[0]) == 1
+    data = samples2[0][0]
+    data["dirs"] = copy.deepcopy(dirs)
+    return data
