@@ -100,15 +100,17 @@ def tiered_alignment(in_bam, tier_num, multi_mappers, extra_args,
         config["algorithm"]["multiple_mappers"] = multi_mappers
         config["algorithm"]["extra_align_args"] = ["-i", int(pair_stats["mean"]),
                                                int(pair_stats["std"])] + extra_args
-        return align_to_sort_bam(nomap_fq1, nomap_fq2, genome_build, "novoalign",
-                                 base_name, base_name,
-                                 dirs, config, dir_ext=os.path.join("hydra", os.path.split(nomap_fq1)[0]))
+        out_bam, ref_file = align_to_sort_bam(nomap_fq1, nomap_fq2, genome_build, "novoalign",
+                                              base_name, base_name,
+                                              dirs, config,
+                                              dir_ext=os.path.join("hydra", os.path.split(nomap_fq1)[0]))
+        return out_bam
     else:
         return None
 
 ## Run hydra to identify structural variation breakpoints
 
-@utils.memoize_outfile(".bed")
+@utils.memoize_outfile(ext=".bed")
 def convert_bam_to_bed(in_bam, out_file):
     """Convert BAM to bed file using BEDTools.
     """
@@ -118,7 +120,7 @@ def convert_bam_to_bed(in_bam, out_file):
                                   stdout=out_handle)
     return out_file
 
-@utils.memoize_outfile("-pair.bed")
+@utils.memoize_outfile(ext="-pair.bed")
 def pair_discordants(in_bed, pair_stats, out_file):
     with file_transaction(out_file) as tx_out_file:
         with open(tx_out_file, "w") as out_handle:
@@ -129,7 +131,7 @@ def pair_discordants(in_bed, pair_stats, out_file):
                                   stdout=out_handle)
     return out_file
 
-@utils.memoize_outfile("-dedup.bed")
+@utils.memoize_outfile(ext="-dedup.bed")
 def dedup_discordants(in_bed, out_file):
     with file_transaction(out_file) as tx_out_file:
         with open(tx_out_file, "w") as out_handle:
