@@ -3,10 +3,11 @@
 import datetime
 import os
 
-from bcbio.upload import shared, filesystem, galaxy
+from bcbio.upload import shared, filesystem, galaxy, s3
 
 _approaches = {"filesystem": filesystem,
-               "galaxy": galaxy}
+               "galaxy": galaxy,
+               "s3": s3}
 
 def from_sample(sample):
     """Upload results of processing from an analysis pipeline sample.
@@ -26,7 +27,7 @@ def _get_files(sample):
     metadata about the file and pipeline versions.
     """
     analysis = sample["info"].get("analysis")
-    if analysis in ["variant", "SNP calling"]:
+    if analysis in ["variant", "SNP calling", "variant2"]:
         return _get_files_variantcall(sample)
     else:
         return []
@@ -42,14 +43,21 @@ def _add_meta(xs, sample):
 def _get_files_variantcall(sample):
     """Return output files for the variant calling pipeline.
     """
-    out = [{"path": sample["summary"]["pdf"],
-            "type": "pdf",
-            "ext": "summary"}]
+    out = []
     algorithm = sample["config"]["algorithm"]
-    if algorithm["aligner"] or algorithm["realign"] or algorithm["recalibrate"]:
+    if algorithm.get("write_summary", True):
+        out = [{"path": sample["summary"]["pdf"],
+                "type": "pdf",
+                "ext": "summary"}]
+    if ((algorithm["aligner"] or algorithm["realign"] or algorithm["recalibrate"])
+          and algorithm.get("merge_bamprep", True)):
         out.append({"path": sample["work_bam"],
                     "type": "bam",
                     "ext": "ready"})
+        if os.path.exists(sample["work_bam"] + ".bai"):
+            out.append({"path": sample["work_bam"] + ".bai",
+                        "type": "bai",
+                        "ext": "ready"})
     for x in sample["variants"]:
         out.append({"path": x["vrn_file"],
                     "type": "vcf",
