@@ -219,6 +219,12 @@ def file_exists(fname):
     """
     return os.path.exists(fname) and os.path.getsize(fname) > 0
 
+def file_uptodate(fname, cmp_fname):
+    """Check if a file exists, is non-empty and is more recent than cmp_fname.
+    """
+    return (file_exists(fname) and file_exists(cmp_fname) and
+            os.path.getmtime(fname) >= os.path.getmtime(cmp_fname))
+
 def create_dirs(config, names=None):
     if names is None:
         names = config["dir"].keys()
@@ -309,7 +315,7 @@ def partition_all(n, iterable):
         if not chunk:
             break
         yield chunk
-
+        
 # ## Dealing with configuration files
 
 def merge_config_files(fnames):
@@ -449,3 +455,21 @@ def replace_directory(out_files, dest_dir):
     else:
         raise ValueError("in_files must either be a sequence of filenames "
                          "or a string")
+
+def which(program):
+    """ returns the path to an executable or None if it can't be found"""
+
+    def is_exe(fpath):
+        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
+
+    fpath, fname = os.path.split(program)
+    if fpath:
+        if is_exe(program):
+            return program
+    else:
+        for path in os.environ["PATH"].split(os.pathsep):
+            exe_file = os.path.join(path, program)
+            if is_exe(exe_file):
+                return exe_file
+
+    return None
