@@ -10,20 +10,21 @@ Variant Evaluation:
 http://www.broadinstitute.org/gsa/wiki/index.php/VariantEval
 """
 import os
+import collections
 import copy
 import itertools
-import collections
+import shutil
 
 from bcbio import broad
 from bcbio.log import logger
-from bcbio.utils import file_exists
+from bcbio.utils import file_exists, safe_makedir
 from bcbio.distributed.transaction import file_transaction
 from bcbio.distributed.split import (parallel_split_combine,
                                      grouped_parallel_split_combine)
 from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_ref_file,
                                    subset_variant_regions)
 from bcbio.variation.realign import has_aligned_reads
-from bcbio.variation import multi
+from bcbio.variation import annotation, bamprep, multi, phasing
 
 # ## GATK Genotype calling
 
@@ -42,22 +43,17 @@ def _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp, region, out_file
     region = subset_variant_regions(variant_regions, region, out_file)
 
     params = ["-R", ref_file,
-              "--annotation", "QualByDepth",
-              "--annotation", "HaplotypeScore",
-              "--annotation", "MappingQualityRankSumTest",
-              "--annotation", "ReadPosRankSumTest",
-              "--annotation", "FisherStrand",
-              "--annotation", "RMSMappingQuality",
-              "--annotation", "DepthOfCoverage",
               "--standard_min_confidence_threshold_for_calling", confidence,
               "--standard_min_confidence_threshold_for_emitting", confidence,
               ]
+    for a in annotation.get_gatk_annotations(config):
+        params += ["--annotation", a]
     for x in align_bams:
         params += ["-I", x]
     if dbsnp:
         params += ["--dbsnp", dbsnp]
     if region:
-        params += ["-L", region, "--interval_set_rule", "INTERSECTION"]
+        params += ["-L", bamprep.region_to_gatk(region), "--interval_set_rule", "INTERSECTION"]
     return broad_runner, params, out_file
 
 def unified_genotyper(align_bams, ref_file, config, dbsnp=None,
@@ -68,7 +64,8 @@ def unified_genotyper(align_bams, ref_file, config, dbsnp=None,
         _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
                                region, out_file)
     if not file_exists(out_file):
-        if not all(has_aligned_reads(x, region) for x in align_bams):
+        if (not isinstance(region, (list, tuple)) and
+            not all(has_aligned_reads(x, region) for x in align_bams)):
             write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
@@ -78,7 +75,7 @@ def unified_genotyper(align_bams, ref_file, config, dbsnp=None,
                 broad_runner.run_gatk(params)
     return out_file
 
-def haplotype_caller(align_bam, ref_file, config, dbsnp=None,
+def haplotype_caller(align_bams, ref_file, config, dbsnp=None,
                        region=None, out_file=None):
     """Call variation with GATK's HaplotypeCaller.
 
@@ -87,8 +84,8 @@ def haplotype_caller(align_bam, ref_file, config, dbsnp=None,
     broad_runner, params, out_file = \
         _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
                                region, out_file)
-    assert broad_runner.has_gatk_full(), \
-        "Require full version of GATK 2.0 for haplotype based calling"
+    assert broad_runner.gatk_type() == "restricted", \
+        "Require full version of GATK 2.4+ for haplotype calling"
     if not file_exists(out_file):
         if not all(has_aligned_reads(x, region) for x in align_bams):
             write_empty_vcf(out_file)
@@ -161,6 +158,8 @@ def variant_filtration(call_file, ref_file, vrn_files, config):
     if caller in ["gatk-haplotype"] and cov_interval not in ["regional"]:
         return _variant_filtration_both(broad_runner, call_file, ref_file, vrn_files,
                                         config)
+    elif caller in ["freebayes"]:
+        return filter_freebayes(broad_runner, call_file, ref_file, vrn_files, config)
     # no additional filtration for callers that filter as part of call process
     elif caller in ["samtools", "varscan"]:
         return call_file
@@ -174,6 +173,12 @@ def variant_filtration(call_file, ref_file, vrn_files, config):
         out_file = "{base}combined.vcf".format(base=os.path.commonprefix(orig_files))
         return combine_variant_files(orig_files, out_file, ref_file, config)
 
+def filter_freebayes(broad_runner, in_file, ref_file, vrn_files, config):
+    """Perform basic sanity filtering of FreeBayes results, removing low confidence calls.
+    """
+    filters = ["QUAL < 20.0", "DP < 5"]
+    return variant_filtration_with_exp(broad_runner, in_file, ref_file, "", filters)
+
 def _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
                          tranch_file, filter_type):
     """Apply recalibration details, returning filtered VCF file.
@@ -428,7 +433,6 @@ def variant_eval(vcf_in, ref_file, dbsnp, target_intervals, picard):
                       "--doNotUseAllStandardModules",
                       "--evalModule", "CompOverlap",
                       "--evalModule", "CountVariants",
-                      "--evalModule", "GenotypeConcordance",
                       "--evalModule", "TiTvVariantEvaluator",
                       "--evalModule", "ValidationReport",
                       "--stratificationModule", "Filter"]
@@ -465,7 +469,7 @@ def _is_bed_file(fname):
 
 # ## High level functionality to run genotyping in parallel
 
-def _get_variantcaller(data):
+def get_variantcaller(data):
     return data["config"]["algorithm"].get("variantcaller", "gatk")
 
 def combine_multiple_callers(data):
@@ -476,7 +480,7 @@ def combine_multiple_callers(data):
         by_bam[x[0]["work_bam"]].append(x[0])
     out = []
     for grouped_calls in by_bam.itervalues():
-        ready_calls = [{"variantcaller": _get_variantcaller(x),
+        ready_calls = [{"variantcaller": get_variantcaller(x),
                         "vrn_file": x.get("vrn_file")}
                        for x in grouped_calls]
         final = grouped_calls[0]
@@ -489,11 +493,11 @@ def combine_multiple_callers(data):
         out.append([final])
     return out
 
-def _handle_multiple_variantcallers(data):
+def handle_multiple_variantcallers(data):
     """Split samples that potentially require multiple variant calling approaches.
     """
     assert len(data) == 1
-    callers = _get_variantcaller(data[0])
+    callers = get_variantcaller(data[0])
     if isinstance(callers, basestring):
         return [data]
     else:
@@ -513,12 +517,12 @@ def parallel_variantcall(sample_info, parallel_fn):
     finished = []
     for x in sample_info:
         if x[0]["config"]["algorithm"]["snpcall"]:
-            to_process.extend(_handle_multiple_variantcallers(x))
+            to_process.extend(handle_multiple_variantcallers(x))
         else:
             finished.append(x)
     if len(to_process) > 0:
         split_fn = process_bam_by_chromosome("-variants.vcf", "work_bam",
-                                             dir_ext_fn = _get_variantcaller)
+                                             dir_ext_fn = get_variantcaller)
         processed = grouped_parallel_split_combine(
             to_process, split_fn, multi.group_batches, parallel_fn,
             "variantcall_sample", "split_variants_by_sample", "combine_variant_files",
@@ -530,6 +534,7 @@ def variantcall_sample(data, region=None, out_file=None):
     """Parallel entry point for doing genotyping of a region of a sample.
     """
     from bcbio.variation import freebayes, cortex, samtools, varscan
+    safe_makedir(os.path.dirname(out_file))
     caller_fns = {"gatk": unified_genotyper,
                   "gatk-haplotype": haplotype_caller,
                   "freebayes": freebayes.run_freebayes,
@@ -544,7 +549,16 @@ def variantcall_sample(data, region=None, out_file=None):
             align_bams = [data["work_bam"]]
         else:
             align_bams = data["work_bam"]
-        data["vrn_file"] = caller_fn(align_bams, sam_ref, config,
-                                     configured_ref_file("dbsnp", config, sam_ref),
-                                     region, out_file)
+        call_vcf = caller_fn(align_bams, sam_ref, config,
+                             configured_ref_file("dbsnp", config, sam_ref),
+                             region, out_file)
+        if data["config"]["algorithm"].get("phasing", "gatk") == "gatk":
+            call_vcf = phasing.read_backed_phasing(call_vcf, align_bams, sam_ref, region, config)
+        if call_vcf != out_file:
+            for ext in ["", ".idx"]:
+                if os.path.exists(call_vcf + ext):
+                    shutil.move(call_vcf + ext, out_file + ext)
+            with open(call_vcf, "w") as out_handle:
+                out_handle.write("Moved to %s" % out_file)
+        data["vrn_file"] = out_file
     return [data]
