@@ -14,6 +14,7 @@ from nose.plugins.attrib import attr
 @contextlib.contextmanager
 def make_workdir():
     remove_old_dir = True
+    #remove_old_dir = False
     dirname = os.path.join(os.path.dirname(__file__), "test_automated_output")
     if remove_old_dir:
         if os.path.exists(dirname):
@@ -37,7 +38,7 @@ class AutomatedAnalysisTest(unittest.TestCase):
         """
         DlInfo = collections.namedtuple("DlInfo", "fname dirname version")
         download_data = [DlInfo("110106_FC70BUKAAXX.tar.gz", None, None),
-                         DlInfo("genomes_automated_test.tar.gz", "genomes", 7),
+                         DlInfo("genomes_automated_test.tar.gz", "genomes", 8),
                          DlInfo("110907_ERP000591.tar.gz", None, None),
                          DlInfo("100326_FC6107FAAXX.tar.gz", None, 3)]
         for dl in download_data:
@@ -99,7 +100,7 @@ class AutomatedAnalysisTest(unittest.TestCase):
 
     @attr(speed=2)
     def test_2_rnaseq(self):
-        """Run an RNA-seq analysis with TopHat and Cufflinks.
+        """Run an RNA-seq analysis with TopHat and generate gene-level counts.
         """
         self._install_test_files(self.data_dir)
         with make_workdir():
@@ -122,6 +123,7 @@ class AutomatedAnalysisTest(unittest.TestCase):
             subprocess.check_call(cl)
 
     @attr(speed=2)
+    @attr(devel=True)
     def test_5_bam(self):
         """Allow BAM files as input to pipeline.
         """
@@ -132,5 +134,3 @@ class AutomatedAnalysisTest(unittest.TestCase):
                   os.path.join(self.data_dir, os.pardir, "100326_FC6107FAAXX"),
                   os.path.join(self.data_dir, "run_info-bam.yaml")]
             subprocess.check_call(cl)
-
-
